#!/usr/bin/env python

import os
import sys

# use local usb
sys.path.insert(0, os.path.abspath('.'))

import usb

ID_VENDOR          = 0x0694
ID_PRODUCT         = 0x0003
WEDO_INTERFACE     = 0
WEDO_CONFIGURATION = 1



def scan_for_devices():
    """ Find all available devices """
    devices = []
    for dev in usb.core.find(find_all=True, idVendor=ID_VENDOR, idProduct=ID_PRODUCT):
        devices.append(dev)
    return devices

class WeDo(object):


    def __init__(self, device):
        self.number = 0
        self.dev = device
        self.valMotorA = 0
        self.valMotorB = 0

    def init_device(self):
        self.dev.set_configuration(WEDO_CONFIGURATION)
        self.endpoint = self.dev[0][(0, 0)][0]

    def getRawData(self):
        return self.endpoint.read(64)[-8:]

    def setMotors(self):
        data = [64, processMotorValues(self.valMotorA) & 0xFF, processMotorValues(self.valMotorB) & 0xFF,
                0x00, 0x00, 0x00, 0x00, 0x00]
        self.dev.ctrl_transfer(bmRequestType=0x21, bRequest=0x09, wValue=0x0200, wIndex=0, data_or_wLength=data)

    def getData(self):
        rawData = self.getRawData()
        if rawData is not None:
            sensorData = {rawData[3]: rawData[2], rawData[5]: rawData[4]}
        else:
            sensorData = {}
        return sensorData


if __name__ == "__main__":
    dev_list = scan_for_devices()
    dev = dev_list[0]
    w = WeDo(dev)
    w.init_device()
    w.valMotorA = 127
    w.valMotorB = 127
    w.setMotors()


